:orphan:

The following are language specific guides for application developers
working with Crossbar.io.

WAMP Programming
================
-  `WAMP Programming in  Python <https://github.com/crossbario/autobahn-python/blob/master/docs/wamp/programming.rst>`__
-  `WAMP Programming in  JavaScript <https://github.com/crossbario/autobahn-js/blob/master/doc/programming.md>`__

Writing Application Components
==============================
-  HTML5 Application Components
-  Node.js Application Components
-  Python Application Components

Advanced Topics
===============
-  :doc:`Database Programming with  PostgreSQL <Database-Programming-with-PostgreSQL>`
-  :doc:`AngularJS Application Component <AngularJS-Application-Components>`
-  :doc:`Session Meta Events and Procedures <Session-Metaevents-and-Procedures>`
-  :doc:`Session Statistics <Session-Statistics>`
-  :doc:`Starting and Stopping Crossbar.io <Starting-and-Stopping-Crossbar.io>`
